@@ -9,6 +9,8 @@ import sys
 # Import libsodium
 if sys.platform.startswith('win'):
     nacl = ctypes.cdll.LoadLibrary('libsodium')
+elif sys.platform.startswith('darwin'):
+    nacl = ctypes.cdll.LoadLibrary('libsodium.dylib')
 else:
     nacl = ctypes.cdll.LoadLibrary('libsodium.so')
 
@@ -61,7 +63,7 @@ def crypto_box_keypair():
     pk, sk = nacl.crypto_box_keypair()
     '''
     pk = ctypes.create_string_buffer(crypto_box_PUBLICKEYBYTES)
-    sk = ctypes.create_string_buffer(crypto_box_PUBLICKEYBYTES)
+    sk = ctypes.create_string_buffer(crypto_box_SECRETKEYBYTES)
     nacl.crypto_box_keypair(pk, sk)
     return pk.raw, sk.raw
 
@@ -136,7 +138,7 @@ def crypto_box_afternm(msg, nonce, k):
         raise ValueError('Invalid nonce')
     pad = b'\x00' * crypto_box_ZEROBYTES + msg
     ctxt = ctypes.create_string_buffer(len(pad))
-    ret = nacl.crypto_box_afternm(ctxt, msg, ctypes.c_ulonglong(len(pad)), nonce, k)
+    ret = nacl.crypto_box_afternm(ctxt, pad, ctypes.c_ulonglong(len(pad)), nonce, k)
     if ret:
         raise ValueError('Unable to encrypt messsage')
     return ctxt.raw[crypto_box_BOXZEROBYTES:]
@@ -203,7 +205,7 @@ def crypto_sign_seed_keypair(seed):
     sk = ctypes.create_string_buffer(crypto_sign_SECRETKEYBYTES)
     vk = ctypes.create_string_buffer(crypto_sign_PUBLICKEYBYTES)
 
-    ret = nacl.crypto_sign_seed_keypair(sk, vk, seed)
+    ret = nacl.crypto_sign_seed_keypair(vk, sk, seed)
     if ret:
         raise CryptError('Failed to generate keypair from seed')
     return vk.raw, sk.raw
